import { __assign } from "tslib";
import { createMotionComponent } from "./motion";
import { allMotionFeatures } from "./render/dom";
import { render } from "./render/dom/render";
import { useDomVisualElement } from "./render/dom/use-dom-visual-element";
import { parseDomVariant } from "./render/dom/utils/parse-dom-variant";
import { htmlElements, svgElements, } from "./render/dom/utils/supported-elements";
/**
 * This is a legacy entry-point for enterprise customers who still need to support IE11.
 * It uses lists to generate `motion` components rather than `Proxy` which increases bundle size.
 * All modern Motion features can be polyfilled except `Proxy`.
 *
 * Usage:
 *
 * ```
 * import { legacyMotion as motion } from "framer-motion/lib/index-legacy"
 * ```
 *
 * This isn't intended to be a publicsed API but something we can point users towards.
 *
 * @internal
 */
var config = {
    defaultFeatures: allMotionFeatures,
    useVisualElement: useDomVisualElement,
    render: render,
    animationControlsConfig: {
        makeTargetAnimatable: parseDomVariant,
    },
};
function createComponents(componentKeys) {
    return componentKeys.reduce(function (acc, key) {
        acc[key] = createMotionComponent(key, config);
        return acc;
    }, {});
}
export var legacyMotion = __assign(__assign(__assign({}, createComponents(htmlElements)), createComponents(svgElements)), { custom: function (Component) {
        return createMotionComponent(Component, config);
    } });
//# sourceMappingURL=index-legacy.js.map