import { useDomVisualElement } from "./use-dom-visual-element";
import { render } from "./render";
import { parseDomVariant } from "./utils/parse-dom-variant";
import { createMotionComponent } from "../../motion";
import { Drag } from "../../motion/features/drag";
import { Gestures } from "../../motion/features/gestures";
import { Exit } from "../../motion/features/exit";
import { Animation } from "../../motion/features/animation";
import { AnimateLayout } from "../../motion/features/layout/Animate";
import { MeasureLayout } from "../../motion/features/layout/Measure";
/**
 * Convert any React component into a `motion` component. The provided component
 * **must** use `React.forwardRef` to the underlying DOM component you want to animate.
 *
 * ```jsx
 * const Component = React.forwardRef((props, ref) => {
 *   return <div ref={ref} />
 * })
 *
 * const MotionComponent = motion.custom(Component)
 * ```
 *
 * @public
 */
export function createMotionProxy(defaultFeatures) {
    var config = {
        defaultFeatures: defaultFeatures,
        useVisualElement: useDomVisualElement,
        render: render,
        animationControlsConfig: {
            makeTargetAnimatable: parseDomVariant,
        },
    };
    function custom(Component) {
        return createMotionComponent(Component, config);
    }
    var componentCache = new Map();
    function get(target, key) {
        if (key === "custom")
            return target.custom;
        if (!componentCache.has(key)) {
            componentCache.set(key, createMotionComponent(key, config));
        }
        return componentCache.get(key);
    }
    return new Proxy({ custom: custom }, { get: get });
}
export var allMotionFeatures = [
    MeasureLayout,
    Animation,
    Drag,
    Gestures,
    Exit,
    AnimateLayout,
];
/**
 * HTML & SVG components, optimised for use with gestures and animation. These can be used as
 * drop-in replacements for any HTML & SVG component, all CSS & SVG properties are supported.
 *
 * @public
 */
export var motion = /*@__PURE__*/ createMotionProxy(allMotionFeatures);
//# sourceMappingURL=index.js.map