import { __assign } from "tslib";
import { HTMLVisualElement } from "./HTMLVisualElement";
import { useConstant } from "../../utils/use-constant";
import { SVGVisualElement } from "./SVGVisualElement";
import { isSVGComponent } from "./utils/is-svg-component";
import { useIsPresent } from "../../components/AnimatePresence/use-presence";
import { useEffect } from "react";
/**
 * DOM-flavoured variation of the useVisualElement hook. Used to create either a HTMLVisualElement
 * or SVGVisualElement for the component.
 *
 */
export var useDomVisualElement = function (Component, props, parent, isStatic, ref) {
    var visualElement = useConstant(function () {
        var DOMVisualElement = isSVGComponent(Component)
            ? SVGVisualElement
            : HTMLVisualElement;
        return new DOMVisualElement(parent, ref);
    });
    visualElement.updateConfig(__assign(__assign(__assign({}, visualElement.config), { enableHardwareAcceleration: !isStatic }), props));
    visualElement.layoutId = props.layoutId;
    var isPresent = useIsPresent();
    visualElement.isPresent =
        props.isPresent !== undefined ? props.isPresent : isPresent;
    useEffect(function () {
        if (props.onViewportBoxUpdate) {
            return visualElement.onViewportBoxUpdate(props.onViewportBoxUpdate);
        }
    }, [props.onViewportBoxUpdate]);
    return visualElement;
};
//# sourceMappingURL=use-dom-visual-element.js.map